spacepy.time.tickrange — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- time - Time conversion, manipulation and implementation of Ticktock class »

# spacepy.time.tickrange

`spacepy.time.` `tickrange`(start, end, deltadays, dtype=None)

  return a Ticktock range given the start, end, and delta

  Parameters: | start : string or number start time (ISO standard string and UTC/datetime do not require a dtype) end : string or number last possible time in series (excluded unless end=start+n*step for integer n) deltadays : float or timedelta step in units of days (float); or datetime timedelta object dtype : string (optional) data type for start, end; e.g. ISO, UTC, RTD, etc. see Ticktock for all options
  Returns: | out : Ticktock instance ticks

  See also

  `Ticktock`

  Examples

      >>> ticks = st.tickrange('2002-02-01T00:00:00', '2002-02-10T00:00:00', deltadays = 1)
      >>> ticks
      Ticktock( ['2002-02-01T00:00:00', '2002-02-02T00:00:00', '2002-02-03T00:00:00',
      '2002-02-04T00:00:00'] , dtype=ISO)

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- time - Time conversion, manipulation and implementation of Ticktock class »